;;; leim-list.el --- sj3-egg setup for the leim API

;; Copyright (C) 2004 Katsumi Yamaoka

;; Author: Katsumi Yamaoka <yamaoka@jpl.org>

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;;; Code:

(put 'sj3-egg-leim 'ready nil)

(put 'sj3-egg-leim 'path
     (let ((lpath (copy-sequence load-path))
	   path)
       (while (and (setq path (let ((load-path lpath))
				(locate-library "sj3-egg")))
		   (progn
		     (setq path
			   (directory-file-name (file-name-directory path)))
		     (file-exists-p (expand-file-name "wnn-egg.elc" path))))
	 (setq lpath (delete (file-name-as-directory path)
			     (delete path lpath))))
       (if path
	   (progn
	     (setq load-path (nconc (delete
				     (file-name-as-directory path)
				     (delete
				      path
				      (delete
				       (expand-file-name "its" path)
				       (delete
					(expand-file-name "its/" path)
					load-path))))
				    (list path)))))
       path))

(put 'sj3-egg-leim 'initialize
     (lambda nil
       (let ((path (get 'sj3-egg-leim 'path)))
	 (if (not path)
	     (erorr "Can't find the sj3-egg ELisp modules")
	   (setq load-path
		 (cons path
		       (delete (file-name-as-directory path)
			       (delete (directory-file-name path)
				       load-path))))
	   (load "egg" nil t)
	   (load "its/han-kata" nil t)
	   (load "its/hira" nil t)
	   (load "its/kata" nil t)
	   (load "its/hankaku" nil t)
	   (load "its/zenkaku" nil t)
	   (setq-default its:*current-map* (its:get-mode-map "roma-kana"))
	   (setq its:*standard-modes*
		 (append
		  (list (its:get-mode-map "roma-kana")
			(its:get-mode-map "roma-kata")
			(its:get-mode-map "downcase")
			(its:get-mode-map "upcase")
			(its:get-mode-map "zenkaku-downcase")
			(its:get-mode-map "zenkaku-upcase"))
		  its:*standard-modes*))
	   (load "sj3-client" nil t)
	   (load "sj3-egg" nil t)
	   (define-key isearch-mode-map "\C-\\"
	     'sj3-egg-isearch-toggle-input-method)
	   (put 'sj3-egg-leim 'ready t)))))

(defun sj3-egg-isearch-toggle-input-method ()
  "Run `isearch-exit' and use `sj3-egg' for entering Japanese text.
This is a replacement for the `isearch-toggle-input-method' function.
You have to activate the `sj3-egg' input method before using this
function in order to search Japanese text.  An easy way to do that is
to put the following lines in your .emacs file:

\(activate-input-method 'japanese-sj3-egg)
\(inactivate-input-method)
"
  (interactive)
  (setq unread-command-events '(?\C-\\))
  (isearch-exit))

(defun sj3-egg-activate (&rest args)
  "Activate the `sj3-egg' input method."
  (if (not (get 'sj3-egg-leim 'ready))
      (funcall (get 'sj3-egg-leim 'initialize)))
  (setq inactivate-current-input-method-function
	(lambda nil
	  (setq inactivate-current-input-method-function nil)
	  (substitute-key-definition 'toggle-input-method
				     'toggle-egg-mode
				     global-map)
	  (toggle-egg-mode)))
  (toggle-egg-mode))

(register-input-method
 "japanese-sj3-egg" "Japanese" 'sj3-egg-activate
 "" "Romaji -> Hiragana -> Kanji&Kana")

;;; Local Variables:
;;; no-byte-compile: t
;;; End:
;;; leim-list.el ends here
